==> nextcloud-14.0.13.zip: nextcloud/apps/gallery/l10n/uk.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Галерея",
    "Your browser is not supported!" : "Ваш браузер не підтримується!",
    "No media files found" : "Відсутні мультимедійні файли.",
    "Configuration error" : "Помилка конфігурації",
    "Error loading slideshow template" : "Помилка завантаження шаблона слайд-шоу",
    "Next" : "Наступний",
    "Play" : "Грати",
    "Pause" : "Пауза",
    "Previous" : "Попередній",
    "Close" : "Закрити",
    "Download" : "Завантажити",
    "Delete" : "Видалити",
    "Share" : "Поділитися",
    "\"{name}\" is an invalid file name." : "\"{name}\" - некоректне ім'я файлу.",
    "File name cannot be empty." : " Ім'я файлу не може бути порожнім.",
    "Upload" : "Вивантажити",
    "Error" : "Помилка",
    "Error while sharing" : "Помилка під час публікації",
    "Error while unsharing" : "Помилка під час відміни публікації",
    "Error while changing permissions" : "Помилка при зміні повноважень",
    "Shared with you and the group {group} by {owner}" : " {owner} опублікував для Вас та для групи {group}",
    "Shared with you by {owner}" : "{owner} опублікував для Вас",
    "Share with users or groups …" : "Поширити серед користувачів або груп ...",
    "Share with users, groups or remote users …" : "Поширити серед локальних чи віддалених користувачів або груп ...",
    "Share link" : "Поділитись посиланням",
    "The public link will expire no later than {days} days after it is created" : "Доступ до опублікованого посилання буде припинено не пізніше ніж через {days} днів з моменту створення",
    "Link" : "Посилання",
    "Password protect" : "Захистити паролем",
    "Password" : "Пароль",
    "Choose a password for the public link" : "Вкажіть пароль для публічного посилання",
    "Allow editing" : "Дозволити редагування",
    "Email link to person" : "Надіслати посилання електронною поштою",
    "Send" : "Надіслати",
    "Set expiration date" : "Встановити термін дії",
    "Expiration" : "Закінчення",
    "Expiration date" : "Термін дії",
    "Adding user..." : "Додавання користувача...",
    "group" : "група",
    "remote" : "Віддалений",
    "Resharing is not allowed" : "Пере-публікація не дозволяється",
    "Unshare" : "Закрити спільний доступ",
    "notify by email" : "повідомити по Email",
    "can share" : "може ділитися з іншими",
    "can edit" : "може редагувати",
    "access control" : "контроль доступу",
    "create" : "створити",
    "change" : "змінити",
    "delete" : "видалити",
    "Password protected" : "Захищено паролем",
    "Error unsetting expiration date" : "Помилка при відміні терміну дії",
    "Error setting expiration date" : "Помилка при встановленні терміну дії",
    "Email sent" : "Лист надіслано",
    "Warning" : "Попередження",
    "This share is password-protected" : "Цей ресурс обміну захищений паролем",
    "The password is wrong. Try again." : "Невірний пароль. Спробуйте ще раз.",
    "Cancel upload" : "Скасувати вивантаження",
    "Sort by name" : "Впорядкувати за ім’ям",
    "Sort by date" : "Сортувати за датою",
    "Album information" : "Інформація про альбом",
    "File list" : "Список файлів",
    "Sorry, this file could not be found." : "Вибачте, цей файл не може бути знайдено.",
    "Reasons might be:" : "Можливі причини:",
    "the file was removed" : "файл був видалений",
    "the file is corrupt" : "файл пошкоджений",
    "Here is the error message returned by the server: " : "Ось повідомлення про помилку, що повертається сервером:",
    "the filesystem is not readable" : "неможливо прочитати файлову систему",
    "the item was removed" : "цей пункт був вилучений",
    "the link has expired" : "посилання застаріло",
    "sharing is disabled" : "обмін заборонений",
    "Picture view" : "Перегляд Зображення",
    "New" : "Створити"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");

==> nextcloud-17.0.6.zip: nextcloud/apps/gallery/l10n/uk.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Галерея",
    "Could not move \"{file}\", target exists" : "Не вдається перемістити файл \"{file}\", він вже існує в точці призначення",
    "Could not move \"{file}\"" : "Неможливо перемістити файл \"{file}\"",
    "No compatible server found at {remote}" : "Відсутній сумісний сервер за адресою {remote}",
    "Your browser is not supported!" : "Ваш браузер не підтримується!",
    "No media files found" : "Відсутні мультимедійні файли.",
    "Configuration error" : "Помилка конфігурації",
    "Error loading slideshow template" : "Помилка завантаження шаблона слайд-шоу",
    "Next" : "Наступний",
    "Play" : "Грати",
    "Pause" : "Пауза",
    "Previous" : "Попередній",
    "Close" : "Закрити",
    "Download" : "Завантажити",
    "Delete" : "Видалити",
    "Share" : "Поділитися",
    "Could not create file \"{file}\" because it already exists" : "Неможливо створити файл \"{file}\", оскільки він вже існує.",
    "Could not create file \"{file}\"" : "Неможливо створити файл \"{file}\"",
    "\"{name}\" is an invalid file name." : "\"{name}\" - некоректне ім'я файлу.",
    "File name cannot be empty." : " Ім'я файлу не може бути порожнім.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" є недопустимим типом файлу",
    "Upload" : "Вивантажити",
    "Error" : "Помилка",
    "Error while sharing" : "Помилка під час публікації",
    "Error while unsharing" : "Помилка під час відміни публікації",
    "Error while changing permissions" : "Помилка при зміні повноважень",
    "Shared with you and the group {group} by {owner}" : " {owner} опублікував для Вас та для групи {group}",
    "Shared with you by {owner}" : "{owner} опублікував для Вас",
    "Share with users or groups …" : "Поширити серед користувачів або груп ...",
    "Share with users, groups or remote users …" : "Поширити серед локальних чи віддалених користувачів або груп ...",
    "Share link" : "Поділитись посиланням",
    "The public link will expire no later than {days} days after it is created" : "Доступ до опублікованого посилання буде припинено не пізніше ніж через {days} днів з моменту створення",
    "Link" : "Посилання",
    "Password protect" : "Захистити паролем",
    "Password" : "Пароль",
    "Choose a password for the public link" : "Вкажіть пароль для публічного посилання",
    "Allow editing" : "Дозволити редагування",
    "Email link to person" : "Надіслати посилання електронною поштою",
    "Send" : "Надіслати",
    "Set expiration date" : "Встановити термін дії",
    "Expiration" : "Закінчення",
    "Expiration date" : "Термін дії",
    "No users or groups found for {search}" : "Не знайдено груп або користувачів за пошуком {search}",
    "No users found for {search}" : "Не знайдено жодного користувача для {search}",
    "An error occurred. Please try again" : "Сталася помилка. Спробуйте ще раз",
    "Adding user..." : "Додавання користувача...",
    "group" : "група",
    "remote" : "Віддалений",
    "Resharing is not allowed" : "Пере-публікація не дозволяється",
    "Unshare" : "Закрити спільний доступ",
    "notify by email" : "повідомити по Email",
    "can share" : "може ділитися з іншими",
    "can edit" : "може редагувати",
    "access control" : "контроль доступу",
    "create" : "створити",
    "change" : "змінити",
    "delete" : "видалити",
    "Password protected" : "Захищено паролем",
    "Error unsetting expiration date" : "Помилка при відміні терміну дії",
    "Error setting expiration date" : "Помилка при встановленні терміну дії",
    "Sending…" : "Відправка...",
    "Email sent" : "Лист надіслано",
    "Warning" : "Попередження",
    "Direct link" : "Пряме посилання",
    "This share is password-protected" : "Цей ресурс обміну захищений паролем",
    "The password is wrong. Try again." : "Невірний пароль. Спробуйте ще раз.",
    "Cancel upload" : "Скасувати вивантаження",
    "Sort by name" : "Впорядкувати за ім’ям",
    "Sort by date" : "Сортувати за датою",
    "Album information" : "Інформація про альбом",
    "File list" : "Список файлів",
    "Sorry, this file could not be found." : "Вибачте, цей файл не може бути знайдено.",
    "Reasons might be:" : "Можливі причини:",
    "the file was removed" : "файл був видалений",
    "the file is corrupt" : "файл пошкоджений",
    "Here is the error message returned by the server: " : "Ось повідомлення про помилку, що повертається сервером:",
    "the filesystem is not readable" : "неможливо прочитати файлову систему",
    "the item was removed" : "цей пункт був вилучений",
    "the link has expired" : "посилання застаріло",
    "sharing is disabled" : "обмін заборонений",
    "Picture view" : "Перегляд Зображення"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
